==> dde-file-manager_5.6.3.orig.tar.xz: dde-file-manager-5.6.3/src/dde-desktop/translations/dde-desktop_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3407"/>
        <source>Icon size</source>
        <translation>Rozmiar ikon</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3415"/>
        <source>Auto merge</source>
        <translation>Automatyczne łączenie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3427"/>
        <source>Auto arrange</source>
        <translation>Automatyczne sortowanie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3464"/>
        <source>Corner Settings</source>
        <translation>Ustawienia narożników</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3473"/>
        <location filename="../view/canvasgridview.cpp" line="3478"/>
        <source>Set Wallpaper</source>
        <translation>Ustaw tapetę pulpitu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3476"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Tapeta pulpitu i wygaszacz ekranu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3655"/>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3455"/>
        <source>Display Settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Tiny</source>
        <translation>Bardzo małe</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Small</source>
        <translation>Małe</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="42"/>
        <source>Medium</source>
        <translation>Średnie</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="43"/>
        <source>Large</source>
        <translation>Duże</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="44"/>
        <source>Super large</source>
        <translation>Bardzo duże</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="725"/>
        <source>Wallpaper Slideshow</source>
        <translation>Pokaz slajdów z tapetami</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="771"/>
        <source>When login</source>
        <translation>Po zalogowaniu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When wakeup</source>
        <translation>Po wybudzeniu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="825"/>
        <source>Require a password on wakeup</source>
        <translation>Wymagaj hasło po wybudzeniu komputera</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="857"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Wait:</source>
        <translation>Odczekaj:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="892"/>
        <source>Wallpaper</source>
        <translation>Tapeta pulpitu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="904"/>
        <source>Screensaver</source>
        <translation>Wygaszacz ekranu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="969"/>
        <source>Loading wallpapers...</source>
        <translation>Wczytywanie tapet...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading screensavers...</source>
        <translation>Wczytywanie wygaszaczy ekranu...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1028"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1029"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Ekran blokady</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1030"/>
        <source>Both</source>
        <translation>Oba</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1105"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Zastosuj</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="394"/>
        <location filename="../view/watermaskframe.cpp" line="395"/>
        <source>Not authorized</source>
        <translation>Nieautoryzowany</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="405"/>
        <location filename="../view/watermaskframe.cpp" line="406"/>
        <source>In trial period</source>
        <translation>W okresie próbnym</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.8.orig.tar.xz: dde-file-manager-5.6.8/src/dde-desktop/translations/dde-desktop_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3451"/>
        <source>Icon size</source>
        <translation>Rozmiar ikon</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3460"/>
        <source>Auto merge</source>
        <translation>Automatyczne łączenie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3472"/>
        <source>Auto arrange</source>
        <translation>Automatyczne sortowanie</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3511"/>
        <source>Corner Settings</source>
        <translation>Ustawienia narożników</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3520"/>
        <location filename="../view/canvasgridview.cpp" line="3525"/>
        <source>Set Wallpaper</source>
        <translation>Ustaw tapetę pulpitu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3523"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Tapeta pulpitu i wygaszacz ekranu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3706"/>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3501"/>
        <source>Display Settings</source>
        <translation>Ustawienia ekranu</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="40"/>
        <source>Tiny</source>
        <translation>Maleńkie</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="41"/>
        <source>Small</source>
        <translation>Małe</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="42"/>
        <source>Medium</source>
        <translation>Średnie</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="43"/>
        <source>Large</source>
        <translation>Duże</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="44"/>
        <source>Super large</source>
        <translation>Bardzo duże</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="727"/>
        <source>Wallpaper Slideshow</source>
        <translation>Pokaz slajdów z tapetami</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="773"/>
        <source>When login</source>
        <translation>Po zalogowaniu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="775"/>
        <source>When wakeup</source>
        <translation>Po wybudzeniu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="827"/>
        <source>Require a password on wakeup</source>
        <translation>Wymagaj hasło po wybudzeniu komputera</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="859"/>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="861"/>
        <source>Wait:</source>
        <translation>Odczekaj:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="894"/>
        <source>Wallpaper</source>
        <translation>Tapeta pulpitu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="906"/>
        <source>Screensaver</source>
        <translation>Wygaszacz ekranu</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="971"/>
        <source>Loading wallpapers...</source>
        <translation>Wczytywanie tapet...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="973"/>
        <source>Loading screensavers...</source>
        <translation>Wczytywanie wygaszaczy ekranu...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1031"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1032"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Ekran blokady</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1033"/>
        <source>Both</source>
        <translation>Oba</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1108"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Zastosuj</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="394"/>
        <location filename="../view/watermaskframe.cpp" line="395"/>
        <source>Not authorized</source>
        <translation>Nieautoryzowany</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="405"/>
        <location filename="../view/watermaskframe.cpp" line="406"/>
        <source>In trial period</source>
        <translation>W okresie próbnym</translation>
    </message>
</context>
</TS>
